@@ -16,5 +16,5 @@
 # You should have received a copy of the GNU General Public License
 # along with HoloPy.  If not, see <http://www.gnu.org/licenses/>.
 
-from .sample import SamplingResult, TemperedSamplingResult, tempered_sample, EmceeStrategy
+from .sample import SamplingResult, TemperedSamplingResult, tempered_sample, EmceeStrategy, TemperedStrategy
 from .noise_model import AlphaModel
